#!/bin/sh
#
# VSP Patch Installation

patchBaseName="1.1.1-ISS-VSP-svm-FP001"

exitStatus=0
if [ x`whoami` != xroot ] ; then
	echo "ERROR: Must be run by root. Aborting." >&2
	exit 1
fi

VSPver=`grep FIRMWARE_VERSION /etc/sysconfig/versions | cut -d"=" -f 2 | sed -e 's/"//g'`
if [ "$VSPver" != "1.1.1" ]; then
	echo "ERROR: This patch is not supported on this VSP version." >&2
	echo "It is for VSP version 1.1.1 only; detected version is: $VSPver" >&2
	echo "Aborting." >&2
	exit 2
fi

echo ""
echo "Beginning Installation of $patchBaseName"
echo ""

daemonStart="false"
ps -e | grep -q issDaemon && {	echo "Detected running issDaemon process; stopping it."
				echo ""
				service issDaemon stop >/dev/null
				daemonStart="true"
		             }

/etc/init.d/iptables stop > /dev/null
grep -q "ISS-INPUT -i eth1 -j ACCEPT" /etc/sysconfig/iptables || sed -i -e "/.*ISS-INPUT.*-i lo -j ACCEPT.*/a-A ISS-INPUT -i eth1 -j ACCEPT" /etc/sysconfig/iptables
/etc/init.d/iptables start > /dev/null

if [ $daemonStart == "true" ]; then
	echo -n "Re-starting issDaemon... "
	service issDaemon start >/dev/null 2>/dev/null && echo "Success" || {
		echo "FAILED"
		echo "" >&2
		echo "An error occurred while attempting to start issDaemon." >&2
		echo "Re-trying; please log any errors and contact support to get further assistance." >&2
		echo "" >&2
		exitStatus=65
		service issDaemon restart
		}
	echo ""
fi

mkdir -p /opt/ISS/
touch /opt/ISS/VSP-Patch-History.log
echo =================== >> /opt/ISS/VSP-Patch-History.log
echo $patchBaseName was installed on >> /opt/ISS/VSP-Patch-History.log
date >> /opt/ISS/VSP-Patch-History.log
echo =================== >> /opt/ISS/VSP-Patch-History.log
echo "Installation finished, if any errors were reported during installation"
echo "please log these errors and contact support to get further assistance."

exit $exitStatus
